@@ -6,11 +6,12 @@ use autodie ':all';
 use namespace::autoclean;
 
 use Type::Library -base, -declare => qw( CFCode ErrorCode);
-use Type::Utils -all;
+# Theres a bug about using undef as a hashref before this version
+use Type::Utils 0.039_12 -all;
 use Types::Standard qw( Enum Maybe);
 use Readonly;
 
-our $VERSION = '0.03_2'; # VERSION
+our $VERSION = '0.03_4'; # VERSION
 
 class_type 'LWP::UserAgent';
 declare CFCode, as Enum[qw( E_UNAUTH E_INVLDINPUT E_MAXAPI)];
@@ -30,7 +31,7 @@ CloudFlare::Client::Types - Types for Cloudflare::Client
 
 =head1 VERSION
 
-version 0.03_2
+version 0.03_4
 
 =head1 SYNOPSIS
 
